import * as Redux from 'redux';
export interface ErrorAction extends Redux.Action {
    payload: any;
    error: boolean;
}
export interface Action<TPayload> extends Redux.Action {
    payload: TPayload;
}
export interface CreateAction<TPayload> extends Action<TPayload> {
    (payload?: TPayload): Action<TPayload>;
    matches(action: Redux.Action): action is Action<TPayload>;
    type: string;
}
export declare const createAction: <TPayload>(type: string) => CreateAction<TPayload>;
export declare type HttpMethod = 'GET' | 'HEAD' | 'PUT' | 'POST' | 'PATCH' | 'DELETE' | 'OPTIONS';
export interface ICallApiOptions {
    endpoint: string;
    method: HttpMethod;
    types: string[];
    body?: any;
    credentials?: 'omit' | 'same-origin' | 'include';
    headers?: {
        [propName: string]: string;
    };
}
export interface ApiAction<TPayload, TResponse> {
    [propName: string]: ICallApiOptions;
}
export interface IApiActionOptions {
    CALL_API: any;
    endpoint: string;
    method: HttpMethod;
    credentials?: 'omit' | 'same-origin' | 'include';
    headers?: {
        [propName: string]: string;
    };
}
export interface CreateApiAsyncAction<TPayload, TResponse> {
    (payload?: TPayload): ApiAction<TPayload, TResponse>;
    matches(action: Action<any>): action is Action<any>;
    matchesPending(action: Action<TPayload>): action is Action<TPayload>;
    matchesSuccess(action: Action<TResponse>): action is Action<TResponse>;
    matchesFailure(action: Action<any>): action is ErrorAction;
    type: string;
}
export declare type CreateApiActionOptions<TPayload> = IApiActionOptions | ((payload: TPayload) => IApiActionOptions);
/**
 * Creates an action creator for api middleware actions.
 *
 * @param {string} type - The action type. Used as a prefix for actions generated by the api middleware
 * @param {IApiActionOptions | (payload: TPayload) => IApiActionOptions} options - The options for the api call
 * @param {any} addOn - (optional) Any additional properties you want to set on the action. NOTE: do not use with redux-api-middleware
 */
export declare const createApiAction: <TPayload, TResponse>(type: string, options: CreateApiActionOptions<TPayload>, addOn?: any) => CreateApiAsyncAction<TPayload, TResponse>;
